TorchPrecomputedTokenizerLoader
===============================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: TorchPrecomputedTokenizerLoader
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TorchPrecomputedTokenizerLoader.__call__
      ~TorchPrecomputedTokenizerLoader.save

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: save
